==> mksddn-forms-handler.1.3.1.zip: mksddn-forms-handler/includes/template-functions.php <==
<?php
/**
 * @file: template-functions.php
 * @description: Global template functions for custom form integration
 * @dependencies: class-utilities.php
 * @created: 2025-10-11
 */

// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Get form action URL for template integration
 *
 * Usage in templates:
 * <form method="post" action="<?php echo mksddn_fh_get_form_action(); ?>">
 *
 * @return string Form action URL
 */
function mksddn_fh_get_form_action(): string {
    return \MksDdn\FormsHandler\Utilities::get_form_action();
}

/**
 * Render required hidden form fields for template integration
 *
 * Usage in templates:
 * <form method="post" action="<?php echo mksddn_fh_get_form_action(); ?>">
 *     <?php mksddn_fh_form_fields('contact-form'); ?>
 *     <!-- Your custom fields here -->
 * </form>
 *
 * @param string $form_slug Form slug or ID
 * @return void
 */
function mksddn_fh_form_fields(string $form_slug): void {
    \MksDdn\FormsHandler\Utilities::render_form_fields($form_slug);
}

/**
 * Get form configuration (fields, settings, etc.)
 *
 * Usage in templates:
 * $form_config = mksddn_fh_get_form_config('contact-form');
 * if ($form_config) {
 *     foreach ($form_config['fields'] as $field) {
 *         // Render field based on configuration
 *     }
 * }
 *
 * @param string $form_slug Form slug or ID
 * @return array|null Form configuration or null if not found
 */
function mksddn_fh_get_form_config(string $form_slug): ?array {
    return \MksDdn\FormsHandler\Utilities::get_form_config($form_slug);
}

/**
 * Get REST API endpoint URL for AJAX form submissions
 *
 * Usage in JavaScript:
 * const endpoint = '<?php echo mksddn_fh_get_rest_endpoint('contact-form'); ?>';
 * fetch(endpoint, { method: 'POST', body: formData });
 *
 * @param string $form_slug Form slug
 * @return string REST API endpoint URL
 */
function mksddn_fh_get_rest_endpoint(string $form_slug): string {
    return \MksDdn\FormsHandler\Utilities::get_rest_endpoint($form_slug);
}

/**
 * Check if form has file upload fields
 *
 * Usage in templates:
 * <form <?php echo mksddn_fh_form_has_files('contact-form') ? 'enctype="multipart/form-data"' : ''; ?>>
 *
 * @param string $form_slug Form slug or ID
 * @return bool True if form has file fields
 */
function mksddn_fh_form_has_files(string $form_slug): bool {
    return \MksDdn\FormsHandler\Utilities::form_has_file_fields($form_slug);
}

/**
 * Enqueue form script for AJAX submission
 * Call this function when you want to enable AJAX form submission
 *
 * Usage in templates:
 * <?php mksddn_fh_enqueue_form_script(); ?>
 *
 * @return void
 */
function mksddn_fh_enqueue_form_script(): void {
    wp_enqueue_script('mksddn-fh-form');
    wp_localize_script(
        'mksddn-fh-form',
        'mksddn_fh_form',
        [
            'sending_text' => __('Sending...', 'mksddn-forms-handler'),
            'send_text'    => __('Send', 'mksddn-forms-handler'),
        ]
    );
}

==> mksddn-forms-handler.2.4.0.zip: mksddn-forms-handler/includes/template-functions.php <==
<?php
/**
 * @file: template-functions.php
 * @description: Global template functions for custom form integration
 * @dependencies: class-utilities.php
 * @created: 2025-10-11
 */

// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Get form action URL for template integration
 *
 * Usage in templates:
 * <form method="post" action="<?php echo mksddn_fh_get_form_action(); ?>">
 *
 * @return string Form action URL
 */
function mksddn_fh_get_form_action(): string {
    return \MksDdn\FormsHandler\Utilities::get_form_action();
}

/**
 * Render required hidden form fields for template integration
 *
 * Usage in templates:
 * <form method="post" action="<?php echo mksddn_fh_get_form_action(); ?>">
 *     <?php mksddn_fh_form_fields('contact-form'); ?>
 *     <!-- Your custom fields here -->
 * </form>
 *
 * @param string $form_slug Form slug or ID
 * @return void
 */
function mksddn_fh_form_fields(string $form_slug): void {
    \MksDdn\FormsHandler\Utilities::render_form_fields($form_slug);
}

/**
 * Get form configuration (fields, settings, etc.)
 *
 * Usage in templates:
 * $form_config = mksddn_fh_get_form_config('contact-form');
 * if ($form_config) {
 *     foreach ($form_config['fields'] as $field) {
 *         // Render field based on configuration
 *     }
 * }
 *
 * @param string $form_slug Form slug or ID
 * @return array|null Form configuration or null if not found
 */
function mksddn_fh_get_form_config(string $form_slug): ?array {
    return \MksDdn\FormsHandler\Utilities::get_form_config($form_slug);
}

/**
 * Get REST API endpoint URL for AJAX form submissions
 *
 * Usage in JavaScript:
 * const endpoint = '<?php echo mksddn_fh_get_rest_endpoint('contact-form'); ?>';
 * fetch(endpoint, { method: 'POST', body: formData });
 *
 * @param string $form_slug Form slug
 * @return string REST API endpoint URL
 */
function mksddn_fh_get_rest_endpoint(string $form_slug): string {
    return \MksDdn\FormsHandler\Utilities::get_rest_endpoint($form_slug);
}

/**
 * Check if form has file upload fields
 *
 * Usage in templates:
 * <form <?php echo mksddn_fh_form_has_files('contact-form') ? 'enctype="multipart/form-data"' : ''; ?>>
 *
 * @param string $form_slug Form slug or ID
 * @return bool True if form has file fields
 */
function mksddn_fh_form_has_files(string $form_slug): bool {
    return \MksDdn\FormsHandler\Utilities::form_has_file_fields($form_slug);
}

/**
 * Enqueue form script for AJAX submission
 * Call this function when you want to enable AJAX form submission
 *
 * Usage in templates:
 * <?php mksddn_fh_enqueue_form_script(); ?>
 *
 * @return void
 */
function mksddn_fh_enqueue_form_script(): void {
    wp_enqueue_script('mksddn-fh-form');
    wp_localize_script(
        'mksddn-fh-form',
        'mksddn_fh_form',
        [
            'sending_text' => __('Sending...', 'mksddn-forms-handler'),
            'send_text' => __('Send', 'mksddn-forms-handler'),
            'success_message' => __('Thank you! Your message has been sent successfully.', 'mksddn-forms-handler'),
            'error_default' => __('Error', 'mksddn-forms-handler'),
            'error_sending' => __('An error occurred while sending the form', 'mksddn-forms-handler'),
            'unauthorized_fields_label' => __('Unauthorized fields:', 'mksddn-forms-handler'),
            'allowed_fields_label' => __('Allowed fields:', 'mksddn-forms-handler'),
            'delivery_status_label' => __('Delivery Status:', 'mksddn-forms-handler'),
            'email_sent_successfully' => __('Email: Sent successfully', 'mksddn-forms-handler'),
            'email_label' => __('Email:', 'mksddn-forms-handler'),
            'telegram_sent_successfully' => __('Telegram: Sent successfully', 'mksddn-forms-handler'),
            'telegram_label' => __('Telegram:', 'mksddn-forms-handler'),
            'google_sheets_data_saved' => __('Google Sheets: Data saved', 'mksddn-forms-handler'),
            'google_sheets_label' => __('Google Sheets:', 'mksddn-forms-handler'),
            'failed' => __('Failed', 'mksddn-forms-handler'),
        ]
    );
}
